using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Runtime.Serialization;
using System.Runtime.InteropServices;
using System.Security.Permissions;

using System.Diagnostics;
using System.Globalization;

using Syncfusion.Diagnostics;
using Syncfusion.Windows.Forms;
using Syncfusion.Drawing;
using Syncfusion.Styles;
using Syncfusion.Windows.Forms.Tools;
using Syncfusion.Windows.Forms.Grid;


namespace CurrencySample
{
	/// <summary>
	/// Summary description for CurrencyCellControl.
	/// </summary>
	public class GridCurrencyCellModel : GridCurrencyTextBoxCellModel
	{
		public GridCurrencyCellModel(GridModel grid) : base(grid)
		{
			
		}

		public override GridCellRendererBase CreateRenderer(GridControlBase control)
		{
			return new GridCurrencyCellRenderer(control, this);
		}
	}

	public class GridCurrencyCellRenderer: GridCurrencyTextBoxCellRenderer
	{

		public GridCurrencyCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
			: base(grid, cellModel)
		{

			//handle these events to set flag allowing editing...
			this.Grid.CurrentCellControlDoubleClick += new ControlEventHandler(grid_CurrentCellControlDoubleClick);
			this.Grid.CurrentCellMoving += new GridCurrentCellMovingEventHandler(grid_CurrentCellMoving);
		}

		bool cellOKtoActivate = false;
		private void grid_CurrentCellMoving(object sender, GridCurrentCellMovingEventArgs e)
		{
			cellOKtoActivate = false;
		}
		private void grid_CurrentCellControlDoubleClick(object sender, ControlEventArgs e)
		{
			cellOKtoActivate = true;
			this.Grid.RefreshRange(CurrentCell.RangeInfo, true);
		}

		//here only call teh baseclass if you want to edit...
		//otherwise draw teh text staticly & draw thw frame if currentcell.
		protected override void OnDraw(System.Drawing.Graphics g, System.Drawing.Rectangle clientRectangle, int rowIndex, int colIndex, Syncfusion.Windows.Forms.Grid.GridStyleInfo style)
		{
			if (cellOKtoActivate)
			{
				base.OnDraw(g, clientRectangle, rowIndex, colIndex, style);
			}
			else
			{
				GridCurrencyEditInfo mi = style.CurrencyEdit;
				style.CellType = "Static";
				 
				Color textColor = mi.PositiveColor;
				string s = "";
				if(style.CellValue != null)
				{
					double d = (double) style.CellValue;
					s = d.ToString(style.Format); 
					if(d < 0)
						textColor = mi.NegativeColor;
				}
				
				GridStaticCellRenderer.DrawText(g, s, style.GdipFont, clientRectangle, style, textColor);
				if(this.ShouldDrawFocused(rowIndex, colIndex))
				{
					Rectangle rect = new Rectangle(clientRectangle.X - 1, clientRectangle.Y - 1,
									clientRectangle.Width + 1, clientRectangle.Height + 1);
					
					g.DrawRectangle(Pens.Black, rect);
				}

			}
		}
	}
}
